@@ -1,4 +1,4 @@
-"""Module providing abstract Node2Vec implementation."""
+"""Module providing Perceptron for edge prediction implementation."""
 from typing import Optional,  Dict, Any, List
 from ensmallen import Graph
 import numpy as np
@@ -7,7 +7,7 @@ from embiggen.edge_prediction.edge_prediction_model import AbstractEdgePredictio
 
 
 class PerceptronEdgePrediction(AbstractEdgePredictionModel):
-    """GCN model for edge prediction."""
+    """Perceptron model for edge prediction."""
 
     def __init__(
         self,
@@ -19,7 +19,7 @@ class PerceptronEdgePrediction(AbstractEdgePredictionModel):
         random_state: int = 42,
         verbose: bool = True
     ):
-        """Create new Kipf GCN object.
+        """Create new Perceptron object.
 
         Parameters
         ------------------------
@@ -177,7 +177,6 @@ class PerceptronEdgePrediction(AbstractEdgePredictionModel):
         return self._model.predict(
             graph=graph,
             node_features=node_features,
-            verbose=self._verbose,
         )
 
     @staticmethod
